@@ -1,7 +1,7 @@
 from rest_framework import routers
 from .views import (
-    AggregateListViewSet, IPAddressListViewSet, ListsRootView, PrefixListViewSet, PrometheusDeviceSD,
-    PrometheusVirtualMachineSD, ServiceListviewSet, TagsListViewSet
+    AggregateListViewSet, DevicesListViewSet, IPAddressListViewSet, ListsRootView, PrefixListViewSet,
+    PrometheusDeviceSD, PrometheusVirtualMachineSD, ServiceListviewSet, TagsListViewSet, VirtualMachinesListViewSet
 )
 
 router = routers.DefaultRouter()
@@ -12,6 +12,8 @@ router.register("ip-addresses", IPAddressListViewSet)
 router.register("aggregates", AggregateListViewSet)
 router.register("services", ServiceListviewSet)
 router.register("tags", TagsListViewSet)
+router.register("devices", DevicesListViewSet, basename="devices")
+router.register("virtual-machines", VirtualMachinesListViewSet, basename="virtual-machines")
 router.register("prometheus-devices", PrometheusDeviceSD)
 router.register("prometheus-vms", PrometheusVirtualMachineSD)
 urlpatterns = router.urls
